/************************************************************
        Copyright (c) 1998 Karl Backstrm

        This code is under GPL - see COPYING.
************************************************************/

#ifndef __LEASESDIALOG_H__
#define __LEASESDIALOG_H__

#include "dhcp.h"
#include <qdialog.h>
#include <qpushbt.h>
#include <qlined.h>
#include <qlistbox.h>
#include <qstring.h>
#include <qstrlist.h>
#include <qgroupbox.h>
#include <qradiobutton.h>
#include <qbuttongroup.h>
#include <qlabel.h>
//#include <ktablistbox.h>

class leasesDialog : public QDialog
{
    Q_OBJECT
public:
    leasesDialog(const char* ipscope, int num, QWidget* parent, const char* name);
    virtual ~leasesDialog();
protected slots:
    void Update_Click();
    void Exit_Click();
    void leasesListSel(int i,int c);
private:
    QList<leasesAddress> *leasesList;
protected:
    int number;
    QString *Subnet;
    void init();
    void update();
    QLabel *label, *ed1, *ed2, *ed3, *ed4;
    QLabel *p1, *p2, *p3, *p4, *p5, *p6;
    QListView *leasesListBox;
    QGroupBox *LeasesBox;
    QPushButton *Update_Button, *Exit_Button;
};

#endif


